@@ -113,6 +113,7 @@ if __name__ == "__main__":
                         "R&D Maestro Continuous Development - WP1 (March-June)": 3,
                         "Task Assignment Visibility Improvements": 3,
                         "20-101747-05-01: KollMorgen System Manager CWAY Replacement": 2}
+
     chart = build_and_schedule(ganttTasksCsvFilePath = 'C:/Users/tburns/Documents/GitHub/coopgantt/tests/testdata/gantt_items.csv',
                                resourceFileCsvFilePath = 'C:/Users/tburns/Documents/GitHub/ProjectGannt/data/resources.csv',
                                resource_max_by_project = resource_max_by_project,
@@ -122,9 +123,10 @@ if __name__ == "__main__":
                                    './gantt_items_scheduled.csv'
                                ])
 
-    build_svgs(chart, output_dirs=['./rendering/svgs'])
+    svg_renderings_dir = './rendering/svgs'
+    build_svgs(chart, output_dirs=[svg_renderings_dir])
 
-    html = create_html(chart, True)
+    html = create_html(chart, svg_input_dir=svg_renderings_dir, embed_css=True)
     save_html(html, 'main.html')
 
 
