@@ -774,7 +774,7 @@ class ScheduledActivity(ABC):
             schedule_start_date = max(schedule_start_date, datetime.today().date())
 
         self._start_date = self.first_eligible_date(schedule_start_date, max_resources_by_type_for_project)
-        logging.debug(f'activity {self} scheduled')
+        logging.debug(f'scheduled activity {self}')
 
     @property
     def is_scheduled(self):
